@@ -5,7 +5,8 @@ import math
 
 from gi.repository import Gio, GLib
 
-from GSettingsWidgets import *
+from SettingsWidgets import SidePage
+from xapp.GSettingsWidgets import *
 
 _270_DEG = 270.0 * (math.pi/180.0)
 _180_DEG = 180.0 * (math.pi/180.0)
@@ -32,7 +33,7 @@ class Module:
             oc_list = self.settings.get_strv("hotcorner-layout")
             self.properties = []
             for item in oc_list:
-                props = item.split(":")
+                props = item.rsplit(":", 2) # Don't split the command (1st el.)
                 self.properties.append(props)
 
             self.corners = []
@@ -59,7 +60,7 @@ class Module:
         oc_list = self.settings.get_strv("hotcorner-layout")
         del self.properties[:]
         for item in oc_list:
-            props = item.split(":")
+            props = item.rsplit(":", 2) # Don't split the command (1st el.)
             self.properties.append(props)
         self.update()
 
@@ -256,7 +257,7 @@ class HotCornerConfiguration(Gtk.Box):
     def on_widget_changed(self, *args):
         def apply(self):
             iter = self.functionCombo.get_active_iter()
-            if iter != None:
+            if iter is not None:
                 function = self.functionStore.get_value(iter, 0)
                 enabled = self.enableSwitch.get_active()
                 delay = str(int(self.hoverDelaySpinner.get_value()))
